.. _installing_python_magic:

Installing ``python-magic``
===========================

Use of the :py:attr:`substanced.file.USE_MAGIC` constant for guessing file
types from stream content requires the ``python-magic`` library, which works
without extra help on most systems, but may require special dependency
installations on Mac OS and Windows systems.  You'll need to follow these
steps on those platforms to use this feature:

Mac OS X

  http://www.brambraakman.com/blog/comments/installing_libmagic_in_mac_os_x_for_python-magic/

Windows

  "Installation on Win32" in https://github.com/ahupp/python-magic
